searchData={"items":[{"type":"module","title":"NewRelic","doc":"New Relic Agent - Public API","ref":"NewRelic.html"},{"type":"function","title":"NewRelic.add_attributes/1","doc":"Report custom attributes on the current Transaction\n\nReporting nested data structures is supported by auto-flattening them\ninto a list of key-value pairs.\n\n```elixir\nNewRelic.add_attributes(foo: \"bar\")\n  # \"foo\" => \"bar\"\n\nNewRelic.add_attributes(map: %{foo: \"bar\", baz: \"qux\"})\n  # \"map.foo\" => \"bar\"\n  # \"map.baz\" => \"qux\"\n  # \"map.size\" => 2\n\nNewRelic.add_attributes(list: [\"a\", \"b\", \"c\"])\n  # \"list.0\" => \"a\"\n  # \"list.1\" => \"b\"\n  # \"list.2\" => \"c\"\n  # \"list.length\" => 3\n```","ref":"NewRelic.html#add_attributes/1"},{"type":"function","title":"Notes - NewRelic.add_attributes/1","doc":"* Nested Lists and Maps are truncated at 10 items since there are a limited number\nof attributes that can be reported on Transaction events","ref":"NewRelic.html#add_attributes/1-notes"},{"type":"function","title":"NewRelic.add_span_attributes/1","doc":"Add additional attributes to the current Span (not the current Transaction).\n\nUseful for reporting additional information about work being done in, for example,\na function being traced with `@trace`","ref":"NewRelic.html#add_span_attributes/1"},{"type":"function","title":"Example - NewRelic.add_span_attributes/1","doc":"```elixir\nNewRelic.add_span_attributes(some: \"attribute\")\n```","ref":"NewRelic.html#add_span_attributes/1-example"},{"type":"function","title":"NewRelic.connect_to_transaction/1","doc":"Advanced:\nCall to manually connect the current process to a Transaction. Pass in a reference\nreturned by `NewRelic.get_transaction/0`\n\nOnly use this when there is no auto-discoverable connection (ex: the process was\nspawned without links or the logic is within a message handling callback).\n\nThis connection will persist until the process exits or\n`NewRelic.disconnect_from_transaction/0` is called.","ref":"NewRelic.html#connect_to_transaction/1"},{"type":"function","title":"NewRelic.create_distributed_trace_payload/1","doc":"See: `NewRelic.distributed_trace_headers/1`","ref":"NewRelic.html#create_distributed_trace_payload/1"},{"type":"function","title":"NewRelic.disconnect_from_transaction/0","doc":"Advanced:\nCall to manually disconnect the current process from the current Transaction.","ref":"NewRelic.html#disconnect_from_transaction/0"},{"type":"function","title":"NewRelic.distributed_trace_headers/1","doc":"You must manually instrument outgoing HTTP calls to connect them to a Distributed Trace.\n\nThe agent will automatically read HTTP request headers and detect if the request is a part\nof an incoming Distributed Trace, but outgoing requests need an extra header:\n\n```elixir\nReq.get(url, headers: [\"x-api-key\": \"secret\"] ++ NewRelic.distributed_trace_headers(:http))\n```","ref":"NewRelic.html#distributed_trace_headers/1"},{"type":"function","title":"Notes - NewRelic.distributed_trace_headers/1","doc":"* Call `distributed_trace_headers` immediately before making the\nrequest since calling the function marks the \"start\" time of the request.","ref":"NewRelic.html#distributed_trace_headers/1-notes"},{"type":"function","title":"NewRelic.exclude_from_transaction/0","doc":"Call to exclude the current process from being part of the Transaction.","ref":"NewRelic.html#exclude_from_transaction/0"},{"type":"function","title":"NewRelic.get_transaction/0","doc":"Advanced:\nReturn a Transaction reference that can be used to manually connect a\nprocess to a Transaction with `NewRelic.connect_to_transaction/1`","ref":"NewRelic.html#get_transaction/0"},{"type":"function","title":"NewRelic.ignore_transaction/0","doc":"Call within a transaction to prevent it from reporting.","ref":"NewRelic.html#ignore_transaction/0"},{"type":"function","title":"Example - NewRelic.ignore_transaction/0","doc":"```elixir\ndef index(conn, _) do\n  NewRelic.ignore_transaction()\n  send_resp(conn, 200, \"Health check OK\")\nend\n```","ref":"NewRelic.html#ignore_transaction/0-example"},{"type":"function","title":"NewRelic.increment_custom_metric/2","doc":"Increment a Custom metric.","ref":"NewRelic.html#increment_custom_metric/2"},{"type":"function","title":"Example - NewRelic.increment_custom_metric/2","doc":"```elixir\nNewRelic.increment_custom_metric(\"My/Metric\")\n```","ref":"NewRelic.html#increment_custom_metric/2-example"},{"type":"type","title":"NewRelic.name/0","doc":"","ref":"NewRelic.html#t:name/0"},{"type":"function","title":"NewRelic.notice_error/2","doc":"Report an Exception inside a Transaction.\n\nThis should only be used when you `rescue` an exception inside a Transaction,\nbut still want to report it. All un-rescued exceptions are already reported as errors.","ref":"NewRelic.html#notice_error/2"},{"type":"function","title":"Example - NewRelic.notice_error/2","doc":"```elixir\ntry do\n  raise RuntimeError\nrescue\n  exception -> NewRelic.notice_error(exception, __STACKTRACE__)\nend\n```","ref":"NewRelic.html#notice_error/2-example"},{"type":"macro","title":"NewRelic.other_transaction/3","doc":"Record an \"Other\" Transaction within the given block. The return value of\nthe block is returned.\n\nSee `start_transaction/2` and `stop_transaction/0` for more details about\nTransactions.","ref":"NewRelic.html#other_transaction/3"},{"type":"macro","title":"Example - NewRelic.other_transaction/3","doc":"```elixir\ndefmodule Worker do\n  use NewRelic.Tracer\n\n  def process_messages do\n    NewRelic.other_transaction(\"Worker\", \"ProcessMessages\") do\n      # ...\n    end\n  end\nend\n```","ref":"NewRelic.html#other_transaction/3-example"},{"type":"macro","title":"NewRelic.other_transaction/4","doc":"","ref":"NewRelic.html#other_transaction/4"},{"type":"function","title":"NewRelic.report_custom_event/2","doc":"Report a Custom event to NRDB.","ref":"NewRelic.html#report_custom_event/2"},{"type":"function","title":"Example - NewRelic.report_custom_event/2","doc":"```elixir\nNewRelic.report_custom_event(\"EventType\", %{\"foo\" => \"bar\"})\n```","ref":"NewRelic.html#report_custom_event/2-example"},{"type":"function","title":"NewRelic.report_custom_metric/2","doc":"Report a Custom metric.","ref":"NewRelic.html#report_custom_metric/2"},{"type":"function","title":"Example - NewRelic.report_custom_metric/2","doc":"```elixir\nNewRelic.report_custom_metric(\"My/Metric\", 123)\n```","ref":"NewRelic.html#report_custom_metric/2-example"},{"type":"function","title":"NewRelic.report_dimensional_metric/4","doc":"Report a Dimensional Metric.\n\nValid types: `:count`, `:gauge`, and `:summary`.","ref":"NewRelic.html#report_dimensional_metric/4"},{"type":"function","title":"Example - NewRelic.report_dimensional_metric/4","doc":"```elixir\nNewRelic.report_dimensional_metric(:count, \"my_metric_name\", 1, %{some: \"attributes\"})\n```","ref":"NewRelic.html#report_dimensional_metric/4-example"},{"type":"function","title":"NewRelic.sample_process/0","doc":"To get detailed information about a particular process, you can install a Process sampler.\nYou must tell the Agent about your process from within the process.\n\nFor a `GenServer`, this function call should be made in the `init` function:\n\n```elixir\ndefmodule ImportantProcess do\n  use GenServer\n  def init(:ok) do\n    NewRelic.sample_process()\n    {:ok, %{}}\n  end\nend\n```\n\nOnce installed, the agent will report `ElixirSample` events with:\n\n* `category = \"Process\"`\n* `message_queue_length`\n* `reductions`\n* `memory_kb`","ref":"NewRelic.html#sample_process/0"},{"type":"function","title":"NewRelic.set_span/2","doc":"Store information about the type of work the current span is doing.","ref":"NewRelic.html#set_span/2"},{"type":"function","title":"Examples - NewRelic.set_span/2","doc":"```elixir\nNewRelic.set_span(:generic, some: \"attribute\")\n\nNewRelic.set_span(:http, url: \"https://elixir-lang.org\", method: \"GET\", component: \"HttpClient\")\n\nNewRelic.set_span(:datastore, statement: statement, instance: instance, address: address,\nhostname: hostname, component: component)\n```","ref":"NewRelic.html#set_span/2-examples"},{"type":"function","title":"NewRelic.set_transaction_name/1","doc":"Set the name of the current transaction.\n\nThe first segment will be treated as the Transaction namespace,\nand commonly contains the name of the framework.","ref":"NewRelic.html#set_transaction_name/1"},{"type":"function","title":"Notes - NewRelic.set_transaction_name/1","doc":"* At least 2 segments are required to light up the Transactions UI in APM\n\nIn the following example, you will see `/custom/transaction/name`\nin the Transaction list.\n\n```elixir\nNewRelic.set_transaction_name(\"/Plug/custom/transaction/name\")\n```","ref":"NewRelic.html#set_transaction_name/1-notes"},{"type":"macro","title":"NewRelic.span/3","doc":"Record a \"Span\" within the given block. The return value of the block is returned.\n\n```elixir\nNewRelic.span(\"do.some_work\", user_id: \"abc123\") do\n  # do some work\nend\n```\n\nNote: You can also use `@trace` annotations to instrument functions without modifying code.","ref":"NewRelic.html#span/3"},{"type":"function","title":"NewRelic.start_transaction/2","doc":"Start an \"Other\" Transaction.\n\nThis will begin monitoring the current process as an \"Other\" Transaction\n(ie: Not a \"Web\" Transaction).\n\nThe first argument will be considered the \"category\", the second is the \"name\".\n\nThe third argument is an optional map of headers that will connect this\nTransaction to an existing Distributed Trace. You can provide W3C \"traceparent\"\nand \"tracestate\" headers or another New Relic agent's \"newrelic\" header.\n\nThe Transaction will end when the process exits, or when you call\n`NewRelic.stop_transaction()`","ref":"NewRelic.html#start_transaction/2"},{"type":"function","title":"Examples - NewRelic.start_transaction/2","doc":"```elixir\nNewRelic.start_transaction(\"GenStage\", \"MyConsumer/EventType\")\nNewRelic.start_transaction(\"Task\", \"TaskName\")\nNewRelic.start_transaction(\"WebSocket\", \"Handler\", %{\"newrelic\" => \"...\"})\n```\n\n> #### Warning {: .error}\n>\n> * You can't start a new transaction within an existing one. Any process\n> spawned inside a transaction belongs to that transaction.\n> * Do _not_ use this for processes that live a very long time, doing so\n> will risk increased memory growth tracking attributes in the transaction!","ref":"NewRelic.html#start_transaction/2-examples"},{"type":"function","title":"Notes - NewRelic.start_transaction/2","doc":"* Don't use this to track Web Transactions - Plug based HTTP servers\nare auto-instrumented based on `telemetry` events.\n* If multiple transactions are started in the same Process, you must\ncall `NewRelic.stop_transaction/0` to mark the end of the Transaction.","ref":"NewRelic.html#start_transaction/2-notes"},{"type":"function","title":"NewRelic.start_transaction/3","doc":"","ref":"NewRelic.html#start_transaction/3"},{"type":"function","title":"NewRelic.stop_transaction/0","doc":"Stop an \"Other\" Transaction.\n\nIf multiple Transactions are started in the same Process, you must\ncall `NewRelic.stop_transaction/0` to mark the end of the Transaction.","ref":"NewRelic.html#stop_transaction/0"},{"type":"type","title":"NewRelic.tx_ref/0","doc":"","ref":"NewRelic.html#t:tx_ref/0"},{"type":"module","title":"NewRelic.Config","doc":"New Relic Agent Configuration\n\nAll configuration items can be set via Environment variables _or_ via `Application` config","ref":"NewRelic.Config.html"},{"type":"function","title":"NewRelic.Config.app_name/0","doc":"**Required**\n\nConfigure your application name. May contain up to 3 names seperated by `;`\n\nApplication name can be configured in two ways:\n* Environment variable: `NEW_RELIC_APP_NAME=MyApp`\n* Application config: `config :new_relic_agent, app_name: \"MyApp\"`","ref":"NewRelic.Config.html#app_name/0"},{"type":"function","title":"NewRelic.Config.automatic_attributes/0","doc":"An optional list of key/value pairs that will be automatic custom attributes\non all event types reported (Transactions, etc). Values are determined at Agent\nstart.\n\nOptions:\n- `{:system, \"ENV_NAME\"}` Read a System ENV variable\n- `{module, function, args}` Call a function.\n- `\"foo\"` A direct value\n\nThis feature is only configurable with `Application` config.\n\nExample:\n\n```elixir\nconfig :new_relic_agent,\n  automatic_attributes: [\n    environment: {:system, \"APP_ENV\"},\n    node_name: {Node, :self, []},\n    team_name: \"Afterlife\"\n  ]\n```","ref":"NewRelic.Config.html#automatic_attributes/0"},{"type":"function","title":"NewRelic.Config.feature/1","doc":"Some Agent features can be controlled via configuration.","ref":"NewRelic.Config.html#feature/1"},{"type":"function","title":"Logs In Context - NewRelic.Config.feature/1","doc":"This feature can be run in multiple \"modes\":\n* `forwarder` The recommended mode which formats outgoing logs as JSON objects\nready to be picked up by a [Log Forwarder](https://docs.newrelic.com/docs/logs/enable-log-management-new-relic/enable-log-monitoring-new-relic/enable-log-management-new-relic)\n* `direct` Logs are buffered in the agent and shipped directly to New Relic. Your logs\nwill continue being output to their normal destination.\n* `disabled` (default)\n\nLogs In Context can be configured in two ways:\n* Environment variable `NEW_RELIC_LOGS_IN_CONTEXT=forwarder`\n* Application config `config :new_relic_agent, logs_in_context: :forwarder`","ref":"NewRelic.Config.html#feature/1-logs-in-context"},{"type":"function","title":"Infinite Tracing - NewRelic.Config.feature/1","doc":"[Infinite Tracing](https://docs.newrelic.com/docs/understand-dependencies/distributed-tracing/infinite-tracing/introduction-infinite-tracing)\ngives you more control of sampling by collecting 100% of Spans and sending them\nto a Trace Observer for processing.\n\nYou can configure your Trace Observer in two ways:\n* Environment variable `NEW_RELIC_INFINITE_TRACING_TRACE_OBSERVER_HOST=trace-observer.host`\n* Application config `config :new_relic_agent, infinite_tracing_trace_observer_host: \"trace-observer.host\"`","ref":"NewRelic.Config.html#feature/1-infinite-tracing"},{"type":"function","title":"NewRelic.Config.feature?/1","doc":"Some Agent features can be toggled via configuration. These all default to `true`, but can be configured in two ways:\n* Environment variables: `NEW_RELIC_ERROR_COLLECTOR_ENABLED=false`\n* Application config: `config :new_relic_agent, error_collector_enabled: false`","ref":"NewRelic.Config.html#feature?/1"},{"type":"function","title":"Built-in features - NewRelic.Config.feature?/1","doc":"* `:distributed_tracing`\n  * Toggles reading of incoming distributed tracing headers\n* `:request_queuing_metrics_enabled`\n  * Toggles collection of request queuing metrics\n* `:extended_attributes`\n  * Toggles reporting extended per-source attributes for datastore, external and function traces","ref":"NewRelic.Config.html#feature?/1-built-in-features"},{"type":"function","title":"Security - NewRelic.Config.feature?/1","doc":"* `:error_collector_enabled`\n  * Toggles collection of any Error traces or metrics\n* `:query_collection_enabled`\n  * Toggles collection of any kind of query string\n* `:function_argument_collection_enabled`\n  * Toggles collection of traced function arguments","ref":"NewRelic.Config.html#feature?/1-security"},{"type":"function","title":"Common library instrumentation - NewRelic.Config.feature?/1","doc":"Opting out of Instrumentation means that `:telemetry` handlers\nwill not be attached, reducing the performance impact to zero.\n\n* `:plug_instrumentation_enabled`\n* `:phoenix_instrumentation_enabled`\n* `:phoenix_live_view_instrumentation_enabled`\n* `:ecto_instrumentation_enabled`\n* `:redix_instrumentation_enabled`\n* `:oban_instrumentation_enabled`\n* `:finch_instrumentation_enabled`\n* `:absinthe_instrumentation_enabled`","ref":"NewRelic.Config.html#feature?/1-common-library-instrumentation"},{"type":"function","title":"NewRelic.Config.host_display_name/0","doc":"Configure the Agent host display name.\n\nThis can help connecting data from the Infrastructure Agent to the APM application.\n\nHost display name can be configured in two ways:\n* Environment variable: `NEW_RELIC_HOST_DISPLAY_NAME=my-host-name`\n* Application config: `config :new_relic_agent, host_display_name: \"my-host-name\"`","ref":"NewRelic.Config.html#host_display_name/0"},{"type":"function","title":"NewRelic.Config.ignore_paths/0","doc":"An optional list of paths that will be used to ignore Web Transactions.\n\nIndividual items can be Strings or Regexes.\n\nCommon use cases include:\n* Ignore health checks: `\"/health\"`\n* Ignore Phoenix longpoll http requests: `\"/live/longpoll\"`\n\nExample:\n```elixir\nconfig :new_relic_agent,\n  ignore_paths: [\n    \"/health\",\n    ~r/longpoll/\n  ]\n```","ref":"NewRelic.Config.html#ignore_paths/0"},{"type":"function","title":"NewRelic.Config.labels/0","doc":"An optional list of labels that will be applied to the application.\n\nConfigured with a single string containing a list of key-value pairs:\n\n`key1:value1;key2:value2`\n\nThe delimiting characters `;` and `:` are not allowed in the `key` or `value`\n\nLabels can be configured in two ways:\n* Environment variables: `NEW_RELIC_LABELS=region:west;env:prod`\n* Application config: `config :new_relic_agent, labels: \"region:west;env:prod\"`","ref":"NewRelic.Config.html#labels/0"},{"type":"function","title":"NewRelic.Config.license_key/0","doc":"**Required**\n\nConfigure your New Relic License Key.\n\nLicense Key can be configured in two ways, though using Environment Variables is strongly\nrecommended to keep secrets out of source code:\n* Environment variables: `NEW_RELIC_LICENSE_KEY=abc123`\n* Application config: `config :new_relic_agent, license_key: \"abc123\"`","ref":"NewRelic.Config.html#license_key/0"},{"type":"function","title":"NewRelic.Config.logger/0","doc":"Configure the Agent logging mechanism.\n\nThis controls how the Agent logs it's own behavior, and doesn't impact your\napplications own logging at all.\n\nDefaults to using `Logger`.\n\nOptions:\n- `\"Logger\"` Send Agent logs to Elixir's `Logger`\n- `\"tmp\"` Write to `tmp/new_relic.log`\n- `\"stdout\"` Write directly to Standard Out\n- `\"file_name.log\"` Write to a chosen file\n\nAgent logging can be configured in two ways:\n* Environment variable: `NEW_RELIC_LOG=stdout`\n* Application config: `config :new_relic_agent, log: \"stdout\"`","ref":"NewRelic.Config.html#logger/0"},{"type":"module","title":"NewRelic.Instrumented.Mix.Task","doc":"","ref":"NewRelic.Instrumented.Mix.Task.html"},{"type":"module","title":"NewRelic.Instrumented.Task","doc":"Provides a pre-instrumented convienince module to connect\nnon-linked `Task` processes to the Transaction that called them.\n\nYou may call these functions directly, or `alias` the module\nand continue to use `Task` as normal.\n\nExample usage:\n```elixir\nalias NewRelic.Instrumented.Task\n\nTask.async_stream([1,2], fn n -> do_work(n) end)\n```","ref":"NewRelic.Instrumented.Task.html"},{"type":"function","title":"NewRelic.Instrumented.Task.async/1","doc":"","ref":"NewRelic.Instrumented.Task.html#async/1"},{"type":"function","title":"NewRelic.Instrumented.Task.async/3","doc":"","ref":"NewRelic.Instrumented.Task.html#async/3"},{"type":"function","title":"NewRelic.Instrumented.Task.async_stream/3","doc":"","ref":"NewRelic.Instrumented.Task.html#async_stream/3"},{"type":"function","title":"NewRelic.Instrumented.Task.async_stream/5","doc":"","ref":"NewRelic.Instrumented.Task.html#async_stream/5"},{"type":"function","title":"NewRelic.Instrumented.Task.await/2","doc":"","ref":"NewRelic.Instrumented.Task.html#await/2"},{"type":"function","title":"NewRelic.Instrumented.Task.await_many/2","doc":"","ref":"NewRelic.Instrumented.Task.html#await_many/2"},{"type":"function","title":"NewRelic.Instrumented.Task.child_spec/1","doc":"","ref":"NewRelic.Instrumented.Task.html#child_spec/1"},{"type":"function","title":"NewRelic.Instrumented.Task.shutdown/2","doc":"","ref":"NewRelic.Instrumented.Task.html#shutdown/2"},{"type":"function","title":"NewRelic.Instrumented.Task.start/1","doc":"","ref":"NewRelic.Instrumented.Task.html#start/1"},{"type":"function","title":"NewRelic.Instrumented.Task.start/3","doc":"","ref":"NewRelic.Instrumented.Task.html#start/3"},{"type":"function","title":"NewRelic.Instrumented.Task.start_link/1","doc":"","ref":"NewRelic.Instrumented.Task.html#start_link/1"},{"type":"function","title":"NewRelic.Instrumented.Task.start_link/3","doc":"","ref":"NewRelic.Instrumented.Task.html#start_link/3"},{"type":"function","title":"NewRelic.Instrumented.Task.yield/2","doc":"","ref":"NewRelic.Instrumented.Task.html#yield/2"},{"type":"function","title":"NewRelic.Instrumented.Task.yield_many/2","doc":"","ref":"NewRelic.Instrumented.Task.html#yield_many/2"},{"type":"module","title":"NewRelic.Instrumented.Task.Supervisor","doc":"Provides a pre-instrumented convienince module to connect\nnon-linked `Task.Supervisor` processes to the Transaction\nthat called them.\n\nYou may call these functions directly, or `alias` the\n`NewRelic.Instrumented.Task` module and continue to use\n`Task` as normal.\n\nExample usage:\n```elixir\nalias NewRelic.Instrumented.Task\n\nTask.Supervisor.async_nolink(\n  MySupervisor,\n  [1,2],\n  fn n -> do_work(n) end\n)\n```","ref":"NewRelic.Instrumented.Task.Supervisor.html"},{"type":"function","title":"NewRelic.Instrumented.Task.Supervisor.async/3","doc":"","ref":"NewRelic.Instrumented.Task.Supervisor.html#async/3"},{"type":"function","title":"NewRelic.Instrumented.Task.Supervisor.async/5","doc":"","ref":"NewRelic.Instrumented.Task.Supervisor.html#async/5"},{"type":"function","title":"NewRelic.Instrumented.Task.Supervisor.async_nolink/3","doc":"","ref":"NewRelic.Instrumented.Task.Supervisor.html#async_nolink/3"},{"type":"function","title":"NewRelic.Instrumented.Task.Supervisor.async_nolink/5","doc":"","ref":"NewRelic.Instrumented.Task.Supervisor.html#async_nolink/5"},{"type":"function","title":"NewRelic.Instrumented.Task.Supervisor.async_stream/4","doc":"","ref":"NewRelic.Instrumented.Task.Supervisor.html#async_stream/4"},{"type":"function","title":"NewRelic.Instrumented.Task.Supervisor.async_stream/6","doc":"","ref":"NewRelic.Instrumented.Task.Supervisor.html#async_stream/6"},{"type":"function","title":"NewRelic.Instrumented.Task.Supervisor.async_stream_nolink/4","doc":"","ref":"NewRelic.Instrumented.Task.Supervisor.html#async_stream_nolink/4"},{"type":"function","title":"NewRelic.Instrumented.Task.Supervisor.async_stream_nolink/6","doc":"","ref":"NewRelic.Instrumented.Task.Supervisor.html#async_stream_nolink/6"},{"type":"function","title":"NewRelic.Instrumented.Task.Supervisor.children/1","doc":"","ref":"NewRelic.Instrumented.Task.Supervisor.html#children/1"},{"type":"function","title":"NewRelic.Instrumented.Task.Supervisor.start_child/3","doc":"","ref":"NewRelic.Instrumented.Task.Supervisor.html#start_child/3"},{"type":"function","title":"NewRelic.Instrumented.Task.Supervisor.start_child/5","doc":"","ref":"NewRelic.Instrumented.Task.Supervisor.html#start_child/5"},{"type":"function","title":"NewRelic.Instrumented.Task.Supervisor.start_link/1","doc":"","ref":"NewRelic.Instrumented.Task.Supervisor.html#start_link/1"},{"type":"function","title":"NewRelic.Instrumented.Task.Supervisor.terminate_child/2","doc":"","ref":"NewRelic.Instrumented.Task.Supervisor.html#terminate_child/2"},{"type":"module","title":"NewRelic.OsMon","doc":"","ref":"NewRelic.OsMon.html"},{"type":"function","title":"NewRelic.OsMon.get_system_memory/0","doc":"","ref":"NewRelic.OsMon.html#get_system_memory/0"},{"type":"function","title":"NewRelic.OsMon.start/0","doc":"","ref":"NewRelic.OsMon.html#start/0"},{"type":"function","title":"NewRelic.OsMon.util/0","doc":"","ref":"NewRelic.OsMon.html#util/0"},{"type":"module","title":"NewRelic.Telemetry.Absinthe","doc":"Provides `Absinthe` instrumentation via `telemetry`\n\nWe automatically gather:\n\n* Transaction name\n* Distributed Trace span events\n\nYou can opt-out of this instrumentation as a whole with `:absinthe_instrumentation_enabled`\nand specifically of query collection with `:query_collection_enabled` via configuration.\nSee `NewRelic.Config` for details.","ref":"NewRelic.Telemetry.Absinthe.html"},{"type":"function","title":"NewRelic.Telemetry.Absinthe.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"NewRelic.Telemetry.Absinthe.html#child_spec/1"},{"type":"module","title":"NewRelic.Telemetry.Ecto","doc":"Provides `Ecto` instrumentation via `telemetry`.\n\nRepos are auto-discovered and instrumented. Make sure your Ecto app depends\non `new_relic_agent` so that the agent can detect when your Repos start.\n\nWe automatically gather:\n\n* Datastore metrics\n* Transaction Trace segments\n* Transaction datastore attributes\n* Distributed Trace span events\n\nYou can opt-out of this instrumentation as a whole with `:ecto_instrumentation_enabled`\nand specifically of query collection with `:query_collection_enabled` via configuration.\nSee `NewRelic.Config` for details.","ref":"NewRelic.Telemetry.Ecto.html"},{"type":"function","title":"NewRelic.Telemetry.Ecto.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"NewRelic.Telemetry.Ecto.html#child_spec/1"},{"type":"module","title":"NewRelic.Telemetry.Finch","doc":"Provides `Finch` instrumentation via `telemetry`.\n\nFinch requests are auto-discovered and instrumented as \"external\" calls.\n\nWe automatically gather:\n* Transaction segments\n* External metrics\n* External spans\n\nYou can opt-out of this instrumentation with `:finch_instrumentation_enabled` via configuration.\nSee `NewRelic.Config` for details.","ref":"NewRelic.Telemetry.Finch.html"},{"type":"function","title":"NewRelic.Telemetry.Finch.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"NewRelic.Telemetry.Finch.html#child_spec/1"},{"type":"function","title":"NewRelic.Telemetry.Finch.handle_event/4","doc":"","ref":"NewRelic.Telemetry.Finch.html#handle_event/4"},{"type":"function","title":"NewRelic.Telemetry.Finch.start_link/1","doc":"","ref":"NewRelic.Telemetry.Finch.html#start_link/1"},{"type":"module","title":"NewRelic.Telemetry.Oban","doc":"Provides `Oban` instrumentation via `telemetry`.\n\nOban jobs are auto-discovered and instrumented.\n\nWe automatically gather:\n\n* Transaction metrics and events\n* Transaction Traces\n* Distributed Traces\n\nYou can opt-out of this instrumentation with `:oban_instrumentation_enabled` via configuration.\nSee `NewRelic.Config` for details.","ref":"NewRelic.Telemetry.Oban.html"},{"type":"function","title":"NewRelic.Telemetry.Oban.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"NewRelic.Telemetry.Oban.html#child_spec/1"},{"type":"module","title":"NewRelic.Telemetry.Phoenix","doc":"Provides `Phoenix` instrumentation via `telemetry`.\n\nThis instrumentation adds extra Phoenix specific instrumentation\non top of the base `NewRelic.Telemetry.Plug` instrumentation.\n\nYou can opt-out of this instrumentation with `:phoenix_instrumentation_enabled` via configuration.\nSee `NewRelic.Config` for details.","ref":"NewRelic.Telemetry.Phoenix.html"},{"type":"function","title":"NewRelic.Telemetry.Phoenix.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"NewRelic.Telemetry.Phoenix.html#child_spec/1"},{"type":"function","title":"NewRelic.Telemetry.Phoenix.handle_event/4","doc":"","ref":"NewRelic.Telemetry.Phoenix.html#handle_event/4"},{"type":"function","title":"NewRelic.Telemetry.Phoenix.start_link/1","doc":"","ref":"NewRelic.Telemetry.Phoenix.html#start_link/1"},{"type":"module","title":"NewRelic.Telemetry.PhoenixLiveView","doc":"Provides Phoenix `LiveView` instrumentation via `telemetry`.\n\nThis instrumentation collects Transactions for the initial LiveView lifecycle events\nthat occur inside the WebSocket process, as well as metrics for subsequent instances\nof lifecycle events.\n\nYou can opt-out of this instrumentation as a whole with `:phoenix_live_view_instrumentation_enabled`,\nand specifically out of params collection with `:function_argument_collection_enabled` via configuration.\n\nSee `NewRelic.Config` for details.","ref":"NewRelic.Telemetry.PhoenixLiveView.html"},{"type":"function","title":"NewRelic.Telemetry.PhoenixLiveView.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"NewRelic.Telemetry.PhoenixLiveView.html#child_spec/1"},{"type":"function","title":"NewRelic.Telemetry.PhoenixLiveView.handle_event/4","doc":"","ref":"NewRelic.Telemetry.PhoenixLiveView.html#handle_event/4"},{"type":"function","title":"NewRelic.Telemetry.PhoenixLiveView.start_link/1","doc":"","ref":"NewRelic.Telemetry.PhoenixLiveView.html#start_link/1"},{"type":"module","title":"NewRelic.Telemetry.Plug","doc":"Provides `Plug` instrumentation via `telemetry`.\n\nPlug pipelines are auto-discovered and instrumented.\n\nWe automatically gather:\n\n* Transaction metrics and events\n* Transaction Traces\n* Distributed Traces\n\nYou can opt-out of this instrumentation with `:plug_instrumentation_enabled` via configuration.\nSee `NewRelic.Config` for details.","ref":"NewRelic.Telemetry.Plug.html"},{"type":"function","title":"NewRelic.Telemetry.Plug.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"NewRelic.Telemetry.Plug.html#child_spec/1"},{"type":"module","title":"NewRelic.Telemetry.Redix","doc":"Provides `Redix` instrumentation via `telemetry`.\n\nRedix connections are auto-discovered and instrumented.\n\nWe automatically gather:\n\n* Datastore metrics\n* Transaction Trace segments\n* Transaction datastore attributes\n* Distributed Trace span events\n\nYou can opt-out of this instrumentation as a whole with `:redix_instrumentation_enabled`\nand specifically of query collection with `:query_collection_enabled` via configuration.\nSee `NewRelic.Config` for details.","ref":"NewRelic.Telemetry.Redix.html"},{"type":"function","title":"NewRelic.Telemetry.Redix.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"NewRelic.Telemetry.Redix.html#child_spec/1"},{"type":"module","title":"NewRelic.Tracer","doc":"Function Tracing\n\nTo enable function tracing in a particular module, `use NewRelic.Tracer`,\nand annotate the functions you want to trace with `@trace`.\n\nTraced functions will report as:\n- Segments in Transaction Traces\n- Span Events in Distributed Traces\n- Special custom attributes on Transaction Events\n\n> #### Warning {: .error}\n>\n> Traced functions will *not* be tail-call-recursive. **Don't use this for recursive functions**.\n\n#### Example\n\nTrace a function:\n\n```elixir\ndefmodule MyModule do\n  use NewRelic.Tracer\n\n  @trace :my_function\n  def my_function do\n    # Will report as `MyModule.my_function/0`\n  end\n\n  @trace :alias\n  def my_function do\n    # Will report as `MyModule.my_function:alias/0`\n  end\nend\n```\n\n#### Arguments\n\nBy default, arguments are inspected and recorded along with traces. You can opt-out of function argument tracing on individual tracers:\n\n```elixir\ndefmodule SecretModule do\n  use NewRelic.Tracer\n\n  @trace {:login, args: false}\n  def login(username, password) do\n    # do something secret...\n  end\nend\n```\n\nThis will prevent the argument values from becoming part of Transaction Traces.\n\nThis may also be configured globally via `Application` config. See `NewRelic.Config` for details.\n\n#### External Service calls\n\n> #### Finch {: .warning}\n>\n> `Finch` requests are auto-instrumented, so you don't need to use `category: :external` tracers or call `set_span` if you use `Finch`.\n> You may still want to use a normal tracer for functions that make HTTP requests if they do additional work worth instrumenting.\n> Automatic `Finch` instrumentation can not inject Distributed Trace headers, so that must still be done manually.\n\nTo manually instrument External Service calls you must give the trace annotation a category.\n\nYou may also call `NewRelic.set_span/2` to provide better naming for metrics & spans, and additionally annotate the outgoing HTTP headers with the Distributed Tracing context to track calls across services.\n\n```elixir\ndefmodule MyExternalService do\n  use NewRelic.Tracer\n\n  @trace {:request, category: :external}\n  def request(method, url, headers) do\n    NewRelic.set_span(:http, url: url, method: method, component: \"HttpClient\")\n    headers ++ NewRelic.distributed_trace_headers(:http)\n    HttpClient.request(method, url, headers)\n  end\nend\n```","ref":"NewRelic.Tracer.html"},{"type":"extras","title":"README","doc":"# New Relic's Elixir agent\n\n[![Build Status](https://github.com/newrelic/elixir_agent/workflows/CI/badge.svg)](https://github.com/newrelic/elixir_agent/actions?query=workflow%3ACI)\n[![Hex.pm Version](https://img.shields.io/hexpm/v/new_relic_agent.svg)](https://hex.pm/packages/new_relic_agent)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-blue.svg)](https://hexdocs.pm/new_relic_agent/)\n[![License](https://img.shields.io/badge/license-Apache%202-blue.svg)](https://opensource.org/licenses/Apache-2.0)\n\nThe experimental open-source Elixir agent allows you to monitor your `Elixir` applications with New Relic. It helps you track transactions, distributed traces, other parts of your application's behavior, and provides an overview of underlying [BEAM activity](https://github.com/newrelic/elixir_agent/wiki/BEAM-stats-page).\n\n[View the Documentation](https://hexdocs.pm/new_relic_agent)","ref":"readme.html"},{"type":"extras","title":"Support Statement - README","doc":"New Relic hosts and moderates an online forum where customers can interact with New Relic employees as well as other customers to get help and share best practices. Like all official New Relic open source projects, there's a related topic in the community forum. You can find this project's topic/threads in the [forum](https://forum.newrelic.com/s/).","ref":"readme.html#support-statement"},{"type":"extras","title":"Contributing - README","doc":"We encourage your contributions to improve [project name]! Keep in mind when you submit your pull request, you'll need to sign the CLA via the click-through using CLA-Assistant. You only have to sign the CLA one time per project. If you have any questions, or to execute our corporate CLA, required if your contribution is on behalf of a company, please drop us an email at [opensource@newrelic.com](mailto:opensource@newrelic.com).\n\nA note about vulnerabilities: As noted in our security policy, New Relic is committed to the privacy and security of our customers and their data. We believe that providing coordinated disclosure by security researchers and engaging with the security community are important means to achieve our security goals.\n\nIf you believe you have found a security vulnerability in this project or any of New Relic's products or websites, we welcome and greatly appreciate you reporting it to New Relic through HackerOne.","ref":"readme.html#contributing"},{"type":"extras","title":"License - README","doc":"The open-source Elixir agent is licensed under the Apache 2.0 License.","ref":"readme.html#license"},{"type":"extras","title":"Installation - README","doc":"Install the [Hex package](https://hex.pm/packages/new_relic_agent)\n\nRequirements:\n* Erlang/OTP 24\n* Elixir 1.11\n\n```elixir\ndefp deps do\n  [\n    {:new_relic_agent, \"~> 1.0\"}\n  ]\nend\n```\n\nIf using an Elixir version before 1.18.x, please also add `:jason` to your dependency list.\n\n```elixir\n{:jason, \"~> 1.0\"}\n```","ref":"readme.html#installation"},{"type":"extras","title":"Configuration - README","doc":"You need to set a few required configuration keys so we can authenticate properly.\n\n#### Via Application config\n\n```elixir\nconfig :new_relic_agent,\n  app_name: \"My App\",\n  license_key: \"license_key\"\n```\n\n#### Via Environment variables\n\nYou can also configure these attributes via `ENV` vars, which helps keep secrets out of source code.\n\n* `NEW_RELIC_APP_NAME`\n* `NEW_RELIC_LICENSE_KEY`\n\n#### HTTP Client Settings\n\n`:httpc` client settings can be overridden if needed. For example, the HTTP connect timeout can be increased which can help alleviate errors related to timeouts connecting to New Relic:\n\n```elixir\nconfig :new_relic_agent,\n  app_name: \"My App\",\n  license_key: \"license_key\",\n  httpc_request_options: [connect_timeout: 5000]\n```","ref":"readme.html#configuration"},{"type":"extras","title":"Telemetry-based Instrumentation - README","doc":"Some common Elixir packages are auto-instrumented via [`telemetry`](https://github.com/beam-telemetry/telemetry)\n\n* [`Plug`](https://github.com/elixir-plug/plug): See [NewRelic.Telemetry.Plug](https://hexdocs.pm/new_relic_agent/NewRelic.Telemetry.Plug.html) for details.\n* [`Phoenix`](https://github.com/phoenixframework/phoenix): See [NewRelic.Telemetry.Phoenix](https://hexdocs.pm/new_relic_agent/NewRelic.Telemetry.Phoenix.html) for details.\n* [`Phoenix LiveView`](https://github.com/phoenixframework/phoenix_live_view): See [NewRelic.Telemetry.PhoenixLiveView](https://hexdocs.pm/new_relic_agent/NewRelic.Telemetry.PhoenixLiveView.html) for details.\n* [`Ecto`](https://github.com/elixir-ecto/ecto): See [NewRelic.Telemetry.Ecto](https://hexdocs.pm/new_relic_agent/NewRelic.Telemetry.Ecto.html) for details.\n* [`Redix`](https://github.com/whatyouhide/redix): See [NewRelic.Telemetry.Redix](https://hexdocs.pm/new_relic_agent/NewRelic.Telemetry.Redix.html) for details.\n* [`Finch`](https://github.com/sneako/finch): See [NewRelic.Telemetry.Finch](https://hexdocs.pm/new_relic_agent/NewRelic.Telemetry.Finch.html) for details.\n* [`Oban`](https://github.com/oban-bg/oban): See [NewRelic.Telemetry.Oban](https://hexdocs.pm/new_relic_agent/NewRelic.Telemetry.Oban.html) for details.\n* [`Absinthe`](https://github.com/absinthe-graphql/absinthe): See [NewRelic.Telemetry.Absinthe](https://hexdocs.pm/new_relic_agent/NewRelic.Telemetry.Absinthe.html) for details.","ref":"readme.html#telemetry-based-instrumentation"},{"type":"extras","title":"Agent features - README","doc":"There are a few agent features that can be enabled via configuration. Please see the documentation for more information.\n\n* [Logs In Context](https://hexdocs.pm/new_relic_agent/NewRelic.Config.html#feature/1-logs-in-context)\n* [Infinite Tracing](https://hexdocs.pm/new_relic_agent/NewRelic.Config.html#feature/1-infinite-tracing)\n* [Security Controls](https://hexdocs.pm/new_relic_agent/NewRelic.Config.html#feature?/1-security)","ref":"readme.html#agent-features"},{"type":"extras","title":"Manual Instrumentation - README","doc":"#### Transactions\n\nTransactions are the main unit of work reported to New Relic. `Plug` and `Phoenix` instrumentation automatically report a Web Transaction for each request. `Oban` instrumentation reports an \"Other\" Transaction for each job. You can also report custom transactions for work done in your app.\n\nThese Transactions will propagate to any process spawned and linked (ex: `Task.async`), but will _not_ follow a process that isn't linked (ex: `Task.Supervisor.async_nolink`).\n\n---\n\nTo manually connect a Transaction to an unlinked process, you can use `NewRelic.get_transaction` and `NewRelic.connect_to_transaction`. See the docs for those functions for further details.\n\n```elixir\ntx = NewRelic.get_transaction()\n\nspawn(fn ->\n  NewRelic.connect_to_transaction(tx)\n  # ...\nend)\n```\n\n---\n\nTo exclude a process from the Transaction:\n\n```elixir\nTask.async(fn ->\n  NewRelic.exclude_from_transaction()\n  Work.wont_be_tracked()\nend)\n```\n\n---\n\nTo prevent reporting an individual transaction:\n\n```elixir\nNewRelic.ignore_transaction()\n```\n\nYou can configure some paths to be automatically ignored:\n\n```elixir\nconfig :new_relic_agent,\n  ignore_paths: [\n    \"/health\",\n    ~r/longpoll/\n  ]\n```\n\n---\n\nIf you are using a `Task` to spawn work, you can use the pre-instrumented `NewRelic.Instrumented.Task` convenience module to make this easier. Just `alias` it in your module and all your Tasks will be instrumented. You may also use the functions directly.\n\n```elixir\nalias NewRelic.Instrumented.Task\n\nTask.Supervisor.async_nolink(MyTaskSupervisor, fn ->\n  # This process will be automatically connected to the current Transaction...\nend)\n```\n\n---\n\nYou may start an \"Other\" Transaction for non-HTTP related work. This could used be while consuming from a message queue, for example.\n\n```elixir\ndefmodule Worker do\n  use NewRelic.Tracer\n\n  def process_messages do\n    NewRelic.other_transaction(\"Worker\", \"ProcessMessages\") do\n      # ...\n    end\n  end\nend\n```\n\n#### Function Tracing\n\n`NewRelic.Tracer` enables detailed Function tracing. Annotate a function and it'll show up as a span in Transaction Traces / Distributed Traces, and we'll collect aggregate stats about it. Install it by adding `use NewRelic.Tracer` to any module, and annotating any function with an `@trace` module attribute\n\n```elixir\ndefmodule MyModule do\n  use NewRelic.Tracer\n\n  @trace :work\n  def work do\n    # Will report as `MyModule.work/0`\n\n    NewRelic.add_span_attributes(some: \"attribute\")\n  end\nend\n```\n\nIf you want to trace a sub-set of a function, you can use the `NewRelic.span` macro.\n\n```elixir\ndefmodule MyModule do\n  use NewRelic.Tracer\n\n  def work do\n    # Do some stuff..\n\n    NewRelic.span \"do.some_work\", user_id: \"abc123\" do\n      # Span will report as `do.some_work` and have a `user_id` attribute\n      # Will return the result of the block\n    end\n  end\nend\n```\n\n#### Distributed Tracing\n\nRequests to other services can be connected with an additional outgoing header.\n\n```elixir\ndefmodule MyExternalService do\n  def request(method, url, headers) do\n    headers = headers ++ NewRelic.distributed_trace_headers(:http)\n    HttpClient.request(method, url, headers)\n  end\nend\n```\n\n#### Mix Tasks\n\n`NewRelic.Instrumented.Mix.Task` To enable the agent and record an Other Transaction during a `Mix.Task`, simply `use NewRelic.Instrumented.Mix.Task`. This will ensure the agent is properly started, records a Transaction, and is shut down.\n\n```elixir\ndefmodule Mix.Tasks.Example do\n  use Mix.Task\n  use NewRelic.Instrumented.Mix.Task\n\n  def run(args) do\n    # ...\n  end\nend\n```\n\n#### Disabling\n\nIf you want to disable the agent, you can do it in two different ways:\n\n* Application config: `config :new_relic_agent, license_key: nil`\n* Environment variables: `NEW_RELIC_HARVEST_ENABLED=false`","ref":"readme.html#manual-instrumentation"},{"type":"extras","title":"CHANGELOG","doc":"","ref":"changelog.html"},{"type":"extras","title":"CHANGELOG - CHANGELOG","doc":"### `v1.32.0`\n\n#### Features\n* Improved Phoenix LiveView instrumentation [#500](https://github.com/newrelic/elixir_agent/pull/500)\n* Support for native JSON library [#494](https://github.com/newrelic/elixir_agent/pull/494) Thanks @TylerWitt!\n\n#### Fixes\n* Fix incomplete bandit response time metrics [#498](https://github.com/newrelic/elixir_agent/pull/498)\n* Fix another bug with missing bandit conn [#497](https://github.com/newrelic/elixir_agent/pull/497)\n* Fix double reported segments in TTs for bandit [#491](https://github.com/newrelic/elixir_agent/pull/491)\n\n#### Tweaks\n* Add transaction.name to Spansaction [#492](https://github.com/newrelic/elixir_agent/pull/492)\n\n------\n\n### `v1.31.1`\n\n#### Fixes\n* Fixes for a few bugs: transaction time attribute, span macro, bandit missing conn [#483](https://github.com/newrelic/elixir_agent/pull/483)\n\n### `v1.31`\n\nA big release after a long time dormant!\n\n#### Notable changes\n* Use Elixir Logger as the default agent logger [#455](https://github.com/newrelic/elixir_agent/pull/455)\n  - Changes where internal New Relic agent logs will go by default\n* Use logger primary filter to hook into error reporting [#466](https://github.com/newrelic/elixir_agent/pull/466)\n  - No longer need to add `ErrorLogger` to your `:logger` `:backend` config\n* Finch Instrumentation [#469](https://github.com/newrelic/elixir_agent/pull/469)\n  - No longer need to `@trace` with `category: :external` to instrument Finch based HTTP requests\n\n#### Features\n* Make Distributed Tracing configurable [#457](https://github.com/newrelic/elixir_agent/pull/457)\n* Support ignoring web transaction paths via configuration [#451](https://github.com/newrelic/elixir_agent/pull/451)\n* Support host display name [#464](https://github.com/newrelic/elixir_agent/pull/464)\n* Oban Instrumentation [#463](https://github.com/newrelic/elixir_agent/pull/463)\n* Absinthe Instrumentation [#471](https://github.com/newrelic/elixir_agent/pull/471)\n* Added `NewRelic.notice_error` to report rescued exceptions [#470](https://github.com/newrelic/elixir_agent/pull/470)\n* Added `NewRelic.add_span_attributes` [#478](https://github.com/newrelic/elixir_agent/pull/478)\n* Added `NewRelic.span` macro [#471](https://github.com/newrelic/elixir_agent/pull/471)\n\n#### Tweaks\n* Doc improvements [#453](https://github.com/newrelic/elixir_agent/pull/453) Thanks @axelson!\n* Performance refactor to use map_reduce [#423](https://github.com/newrelic/elixir_agent/pull/423) Thanks @bradhanks!\n* Handle binary attribute values better [#458](https://github.com/newrelic/elixir_agent/pull/458)\n* Safer math in Process sampler [#461](https://github.com/newrelic/elixir_agent/pull/461)\n* Speed up BackoffSampler with counters [#460](https://github.com/newrelic/elixir_agent/pull/460)\n* Conditional compilation to address warnings [#456](https://github.com/newrelic/elixir_agent/pull/456)\n* Add spansaction for regular DT [#467](https://github.com/newrelic/elixir_agent/pull/467)\n* Only start telemetry handlers when agent is enabled [#474](https://github.com/newrelic/elixir_agent/pull/474)\n* Only start os_mon when agent enabled [#473](https://github.com/newrelic/elixir_agent/pull/473)\n* Add extended attributes for function tracers, make extended attributes configurable [#479](https://github.com/newrelic/elixir_agent/pull/479)\n\n#### Fixes\n* Handle when Bandit telemetry doesn't include the conn [#449](https://github.com/newrelic/elixir_agent/pull/449)\n* Fix a few Bandit attributes [#480](https://github.com/newrelic/elixir_agent/pull/480)\n* Enable Logger calls to be compile time purgable [#402](https://github.com/newrelic/elixir_agent/pull/402) Thanks @TylerWitt!\n* Tracer - Create a proper list when tail of list is ignored [#465](https://github.com/newrelic/elixir_agent/pull/465)\n* Add bandit optional dependency [#472](https://github.com/newrelic/elixir_agent/pull/472)\n\n------\n\n### `v1.30`\n\nFeatures\n* adjust metadata_reporter :transaction report_error [#443](https://github.com/newrelic/elixir_agent/pull/443)\n* Identify Phoenix LiveView metrics [#424](https://github.com/newrelic/elixir_agent/pull/424)\n* Add Bandit HTTP server support [#445](https://github.com/newrelic/elixir_agent/pull/445)\n\n------\n\n### `v1.29`\n\nFeatures\n* Ensure working support for newer versions, up to Erlang 26 and Elixir 15\n  [#420](https://github.com/newrelic/elixir_agent/pull/420),\n  [#421](https://github.com/newrelic/elixir_agent/pull/421),\n  [#426](https://github.com/newrelic/elixir_agent/pull/426),\n  [#427](https://github.com/newrelic/elixir_agent/pull/427). Thank you so\n  much @tmaszk and @XiXiaPdx!\n\n------\n\n### `v1.28`\n\nFeatures\n* Add feature to remove function argument data from stacktraces reported to New Relic.\n[#417](https://github.com/newrelic/elixir_agent/pull/417) Thanks @griffitr!\n* Add support for [Dimensional Metrics](https://docs.newrelic.com/docs/query-your-data/nrql-new-relic-query-language/nrql-query-tutorials/query-infrastructure-dimensional-metrics-nrql/).\n[#408](https://github.com/newrelic/elixir_agent/pull/408) Thanks @XiXiaPdx!\n\n------\n\n### `v1.27.8`\n\nFeatures\n* Allow user to provide global override of some HTTP client settings. [#391](https://github.com/newrelic/elixir_agent/pull/391) Thanks @edds!\n\n### `v1.27.7`\n\nFixes\n* Handle DT payload with unknown version. [#374](https://github.com/newrelic/elixir_agent/pull/374) Thanks @renanlage!\n\n### `v1.27.6`\n\nTweaks\n* Update Telemetry dependency to allow Telemetry 1.0. [#363](https://github.com/newrelic/elixir_agent/pull/363) Thanks @jimsynz!\n\n### `v1.27.5`\n\nFixes\n* Avoid a race condition during Task instrumentation compilation. [#359](https://github.com/newrelic/elixir_agent/pull/359) Thanks @mhanberg!\n\n### `v1.27.4`\n\nFixes\n* Don't fail an Other Transaction upon expected error. [#357](https://github.com/newrelic/elixir_agent/pull/357)\n\n### `v1.27.3`\n\nFixes\n* Fix categorization of simple SQL queries in Ecto. [#354](https://github.com/newrelic/elixir_agent/pull/354) Thanks @mrz!\n\n### `v1.27.2`\n\nFixes\n* Fix a leak in other transactions when not manually closed. [#352](https://github.com/newrelic/elixir_agent/pull/352)\n\n### `v1.27.1`\n\nFeatures\n* Auto-require `NewRelic` in `use NewRelic.Tracer` for convenience. [#350](https://github.com/newrelic/elixir_agent/pull/350)\n\n### `v1.27.0`\n\nFeatures\n* Include start_link in transaction tracing. [#344](https://github.com/newrelic/elixir_agent/pull/344)\n\n------\n\n### `v1.26.0`\n\nFeatures\n* Increase timestamp resolution. [#343](https://github.com/newrelic/elixir_agent/pull/343)\n\n------\n\n### `v1.25.3`\n\nFixes\n* Handle exception asking for remote process name. [#342](https://github.com/newrelic/elixir_agent/pull/342) Thanks @benhaney!\n\n### `v1.25.2`\n\nFixes\n* Fix edge case in new `Ecto` table name parsing. [#340](https://github.com/newrelic/elixir_agent/pull/340)\n\n### `v1.25.1`\n\nFixes\n* Fix edge case in new `Ecto` table name parsing. [#338](https://github.com/newrelic/elixir_agent/pull/338)\n\n### `v1.25.0`\n\nFeatures\n* Support for any `Ecto` adapter, including Sqlite and MSSQL. [#337](https://github.com/newrelic/elixir_agent/pull/337) Thanks @marocchino!\n\n------\n\n### `v1.24.5`\n\nFixes\n* Ensure instrumentation calls don't fail if app not started. [#332](https://github.com/newrelic/elixir_agent/pull/332)\n\n### `v1.24.4`\n\nTweaks\n* Support per-log message metadata. [#330](https://github.com/newrelic/elixir_agent/pull/330) Thanks @mattgibson!\n* Properly render IO list log message. [#329](https://github.com/newrelic/elixir_agent/pull/329) Thanks @mattgibson!\n\n### `v1.24.3`\n\nFixes\n* Fix Telemetry API URLs for EU customers. [#326](https://github.com/newrelic/elixir_agent/pull/326) Thanks @mattgibson!\n\n### `v1.24.2`\n\nTweaks\n* Use `castore` for certificates. [#320](https://github.com/newrelic/elixir_agent/pull/320) Thanks @chulkilee!\n\n### `v1.24.1`\n\nTweaks\n* Add a helper module for auto-instrumenting a `Task`. [#318](https://github.com/newrelic/elixir_agent/pull/318)\n\n### `v1.24.0`\n\nFeatures\n* `Plug` instrumentation is now fully automatic based on `telemetry` events!\n  * Please remove deprecated calls:\n    - `use NewRelic.Transaction`\n    - `NewRelic.Transaction.handle_errors/2`\n* `Phoenix` instrumentation is now fullly automatic based on `telemetry` events!\n  * Please remove deprecated instrumentation library:\n    - https://github.com/binaryseed/new_relic_phoenix\n* Transaction tracking is now faster and better in the face of overload\n  * Note: Transactions no longer follow processes that aren't linked (ex: `Task.Supervisor.async_nolink`). They can be connected manually if desired using `NewRelic.connect_to_transaction`.\n\n------\n\n### `v1.23.6`\n\nFixes\n* Coerce Transaction Trace segment attribute values. [#316](https://github.com/newrelic/elixir_agent/pull/316)\n\n### `v1.23.5`\n\nFixes\n* Inspect failed output going to log. [#315](https://github.com/newrelic/elixir_agent/pull/315)\n\n### `v1.23.4`\n\nTweaks\n* Add ability to increment custom metric. [#314](https://github.com/newrelic/elixir_agent/pull/314) Thanks @edds!\n\n### `v1.23.3`\n\nTweaks\n* Add automatic attributes to the Spansaction. [#312](https://github.com/newrelic/elixir_agent/pull/312)\n* Track tracer reductions. [#313](https://github.com/newrelic/elixir_agent/pull/313)\n\n### `v1.23.2`\n\nTweaks\n* Minor change to External span tracer attributes. [#311](https://github.com/newrelic/elixir_agent/pull/311)\n\n### `v1.23.1`\n\nTweaks\n* Improve External span names. [#309](https://github.com/newrelic/elixir_agent/pull/309)\n\n### `v1.23.0`\n\nFeatures\n* Adds support for Infinite Tracing. [#307](https://github.com/newrelic/elixir_agent/pull/307)\n\n------\n\n### `v1.22.6`\n\nTweaks\n* Add `ERTS Version` to environment values. [#302](https://github.com/newrelic/elixir_agent/pull/302)\n\n### `v1.22.5`\n\nFixes\n* Handle formatting exit edge case. [#300](https://github.com/newrelic/elixir_agent/pull/300)\n* Work around CPU util shutdown issue. [#301](https://github.com/newrelic/elixir_agent/pull/301)\n\n### `v1.22.4`\n\nFeatures\n* Adds a macro for defining an Other Transaction. [#264](https://github.com/newrelic/elixir_agent/pull/264)\n\nFixes\n* Handle when a string winds up in a stacktrace list. [#294](https://github.com/newrelic/elixir_agent/pull/294)\n* Properly handle boolean config option. [#295](https://github.com/newrelic/elixir_agent/pull/295)\n* Prevent error when bad attribute values get in. [#296](https://github.com/newrelic/elixir_agent/pull/296)\n\n### `v1.22.3`\n\nTweaks\n* Make request queuing collection configurable [#292](https://github.com/newrelic/elixir_agent/pull/292)\n\n### `v1.22.2`\n\nTweaks\n* Optimize metric aggregation with `:counter`\n\n### `v1.22.1`\n\nFixes\n* Fix a compile time warning about `:scheduler` [#288](https://github.com/newrelic/elixir_agent/pull/288)\n* Avoid a shutdown bug in `:cpu_sup` [#287](https://github.com/newrelic/elixir_agent/pull/287)\n\n### `v1.22.0`\n\nFeatures\n* Report a custom metric. [#283](https://github.com/newrelic/elixir_agent/pull/283)\n\n------\n\n### `v1.21.2`\n\nFixes\n* Handle encoding an unexpected nil sampled flag. [#282](https://github.com/newrelic/elixir_agent/pull/282)\n\n### `v1.21.1`\n\nFixes\n* Properly handle a bad tracestate sampled / priority value. [#273](https://github.com/newrelic/elixir_agent/pull/273)\n\n### `v1.21.0`\n\nFeatures\n* Logs in context - connect `Logger` messages to the current Distributed Trace / Error Trace. [#272](https://github.com/newrelic/elixir_agent/pull/272)\n\nLogs in context requires Elixir 1.10 or greater.\n\n------\n\n### `v1.20.0`\n\nRemovals:\n* Stop reporting redundant `ElixirAggregate` custom events for `Transaction`. [#276](https://github.com/newrelic/elixir_agent/pull/276)\n* Stop reporting redundant `ElixirAggregate` custom events for `FunctionTrace`. [#277](https://github.com/newrelic/elixir_agent/pull/277)\n\nAlternatives for querying this data are available and noted in the PRs.\n\nFixes\n* Don't warn for untraced functions. [#269](https://github.com/newrelic/elixir_agent/pull/269) Thanks @barthez!\n* Spread the Samplers across the full sample cycle. [#278](https://github.com/newrelic/elixir_agent/pull/278)\n\n------\n\n### `v1.19.7`\n\nTweaks\n* Log the number of events seen by harvesters. [#274](https://github.com/newrelic/elixir_agent/pull/274)\n\n### `v1.19.6`\n\nFixes\n* Properly handle bad values in Custom and Span Events. [#267](https://github.com/newrelic/elixir_agent/pull/267) & [#268](https://github.com/newrelic/elixir_agent/pull/268)\n\n### `v1.19.5`\n\nFixes\n* Fix memory leak in long running transactions. [#263](https://github.com/newrelic/elixir_agent/pull/263) Thanks @mopp!\n\n### `v1.19.4`\n\nFixes\n* Fix tracer compilation bug. [#255](https://github.com/newrelic/elixir_agent/pull/255)\n\n### `v1.19.3`\n\nFeatures\n* Report more Error metrics based on transaction type. [#251](https://github.com/newrelic/elixir_agent/pull/251)\n\n### `v1.19.2`\n\nTweaks\n* Optimize memory usage in Metric harvester. [#242](https://github.com/newrelic/elixir_agent/pull/242)\n* Silence warnings in Elixir 1.10. [#243](https://github.com/newrelic/elixir_agent/pull/243)\n\n### `v1.19.1`\n\nFixes\n* Fix a regression from 1.18 with Transaction error attribute. [#240](https://github.com/newrelic/elixir_agent/pull/240)\n\n### `v1.19.0`\n\nFeatures\n* Automatic `Redix` instrumentation based on `telemetry` events! [#210](https://github.com/newrelic/elixir_agent/pull/210)\n\n------\n\n### `v1.18.5`\n\nFixes\n\n* Fix one more tracer compilation bug. [#239](https://github.com/newrelic/elixir_agent/pull/239)\n\n### `v1.18.4`\n\nFixes\n\n* Fix another interesting tracer compilation bug. [#235](https://github.com/newrelic/elixir_agent/pull/235)\n\n### `v1.18.3`\n\nFixes\n\n* Fix another tracer compilation bug. [#230](https://github.com/newrelic/elixir_agent/pull/230)\n\n### `v1.18.2`\n\nFixes\n\n* Fix a tracer compilation bug. [#228](https://github.com/newrelic/elixir_agent/pull/228)\n\n### `v1.18.1`\n\nTweaks\n\n* Report additional Datastore metrics. [#224](https://github.com/newrelic/elixir_agent/pull/224)\n\n### `v1.18.0`\n\nFeatures\n\n* Read the Docker container ID for accurate container detection. [#207](https://github.com/newrelic/elixir_agent/pull/207) Thanks @alejandrodnm!\n* Report Ecto queries that result in an error. [#202](https://github.com/newrelic/elixir_agent/pull/202)\n* Coerce and handle all custom attribute values. [#205](https://github.com/newrelic/elixir_agent/pull/205)\n* `Mix.Task` instrumentation. [#221](https://github.com/newrelic/elixir_agent/pull/221)\n\nTweaks\n\n* Make `plug_cowboy` an optional dep. [#201](https://github.com/newrelic/elixir_agent/pull/201)\n* Use Erlang/OTP 21+ built-in SSL hostname verification. [#197](https://github.com/newrelic/elixir_agent/pull/197)\n* Reduce contention on transaction storage. [#209](https://github.com/newrelic/elixir_agent/pull/209)\n* Detect Ecto repo via telemetry event instead of an Erlang tracer. [#214](https://github.com/newrelic/elixir_agent/pull/214)\n* Fix for Distributed Traces that start from a Browser Agent. [#215](https://github.com/newrelic/elixir_agent/pull/215)\n* Fix for error reporting during Other Transactions. [#220](https://github.com/newrelic/elixir_agent/pull/220) Thanks @prabello.\n\n------\n\n### `v1.17.1`\n\nFixes\n\n* Handle cases where another New Relic agent sends a bad `tracestate` header. [#206](https://github.com/newrelic/elixir_agent/pull/206)\n\n### `v1.17.0`\n\nFeatures\n\n* Report \"Scoped\" Transaction metrics:\n  * Externals [#175](https://github.com/newrelic/elixir_agent/pull/175)\n  * Function traces [#189](https://github.com/newrelic/elixir_agent/pull/189)\n  * Database calls [#195](https://github.com/newrelic/elixir_agent/pull/195)\n\n* Enable disabling function argument tracing globally & per-trace. [#186](https://github.com/newrelic/elixir_agent/pull/186)\n\n* Provide an API for manually stopping an Other transaction. [#198](https://github.com/newrelic/elixir_agent/pull/198)\n\n------\n\n### `v1.16.7`\n\nFixes\n\n* Handle Ecto stream telemetry results. [#192](https://github.com/newrelic/elixir_agent/pull/192)\n\n### `v1.16.6`\n\nFixes\n\n* Prevent boot process from getting blocked if New Relic is slow. [#187](https://github.com/newrelic/elixir_agent/pull/187)\n\n### `v1.16.5`\n\nFixes\n\n* Fix macro compilation with Elixir `1.10`. Thanks @ethangunderson! [#185](https://github.com/newrelic/elixir_agent/pull/185)\n\n### `v1.16.4`\n\nTweaks\n\n* Remove ecto metadata catchall for better debugging.\n\n### `v1.16.3`\n\nFixes\n\n* Fix sampling decision default value. [#177](https://github.com/newrelic/elixir_agent/pull/177)\n\n### `v1.16.2`\n\nFixes\n\n* Handle error queries properly. [#173](https://github.com/newrelic/elixir_agent/pull/173)\n\n### `v1.16.1`\n\nFixes\n\n* Safely access optional Ecto config attributes. [#172](https://github.com/newrelic/elixir_agent/pull/172)\n\n### `v1.16.0`\n\nFeatures\n\n* Support the W3C Trace Context spec for Distributed Tracing. [#169](https://github.com/newrelic/elixir_agent/pull/169)\n* Upgrade to New Relic \"Protocol 17\" which includes support for faster event harvest (sent every 5 seconds!). [#168](https://github.com/newrelic/elixir_agent/pull/168)\n\n------\n\n### `v1.15.0`\n\nFeatures\n\n* Adds automatic Ecto instrumentation via `telemetry`. [#161](https://github.com/newrelic/elixir_agent/pull/161)\n* Deprecates `@trace {_, category: :datastore}`. These trace annotations will now be ignored, and a warning logged during compilation.\n  * Metric name change: Datastore Metrics reported now follow New Relic naming conventions, based on the table name\n\n------\n\n### `v1.14.0`\n\nFeatures\n\n* Minor internal refactor to enable reporting spans after they complete. [#160](https://github.com/newrelic/elixir_agent/pull/160)\n\n------\n\n### `v1.13.1`\n\nFixes\n\n* Handle rare edge cases connecting to New Relic. [#156](https://github.com/newrelic/elixir_agent/pull/156)\n\n### `v1.13.0`\n\nFeatures\n\n* `OTP 21+` has been required for a while, and now the agent will enforce this version requirement [#151](https://github.com/newrelic/elixir_agent/pull/151)\n* Truncate super large nested attribute structure [#153](https://github.com/newrelic/elixir_agent/pull/153)\n\n------\n\n### `v1.12.0`\n\nFeatures\n\n* Add support for detecting request queuing via `x-request-start`. [#143](https://github.com/newrelic/elixir_agent/pull/143) Thanks @sb8244!\n  - https://docs.newrelic.com/docs/apm/applications-menu/features/configure-request-queue-reporting\n\n------\n\n### `v1.11.0`\n\nFeatures\n\n* Add support for detecting if the app is running inside Kubernetes. [#140](https://github.com/newrelic/elixir_agent/pull/140)\n\n------\n\n### `v1.10.2`\n\nFixes\n\n* Protect against huge arguments blowing out memory [#136](https://github.com/newrelic/elixir_agent/pull/136)\n\n### `v1.10.1`\n\nTweaks\n\n* Handle lists inside objects passed to `add_attributes` [#135](https://github.com/newrelic/elixir_agent/pull/135) Thanks @emeryotopalik!\n\n### `v1.10.0`\n\nFeatures\n\n* Add an option to not track `async_nolink` task as part of the Transaction. [#123](https://github.com/newrelic/elixir_agent/pull/123)\n* Ignore extraneous Plug errors (ie: 400s). [#125](https://github.com/newrelic/elixir_agent/pull/125)\n\nTweaks\n\n* Improve formatting of ErlangError. [#126](https://github.com/newrelic/elixir_agent/pull/126)\n\n------\n\n### `v1.9.12`\n\nFixes\n\n* Prevent a rare harvester leak. [#124](https://github.com/newrelic/elixir_agent/pull/124)\n\n### `v1.9.11`\n\nFixes\n\n* Protect against missing attribute under race condition. [#120](https://github.com/newrelic/elixir_agent/pull/120)\n\n### `v1.9.10`\n\nFixes\n\n* Revert `async_nolink` change. [#119](https://github.com/newrelic/elixir_agent/pull/119)\n\n### `v1.9.9`\n\nFixes\n\n* Fix a race condition around error reporting and `async_nolink` [#118](https://github.com/newrelic/elixir_agent/pull/118). Thanks @zoevkay!\n\n### `v1.9.8`\n\nFixes\n\n* Fix a bug causing extra spans to be reported [#116](https://github.com/newrelic/elixir_agent/pull/116)\n\n### `v1.9.7`\n\nTweaks\n\n* Improve formatting for `EXIT` errors\n  - [#112](https://github.com/newrelic/elixir_agent/pull/112)\n  - [#113](https://github.com/newrelic/elixir_agent/pull/113)\n\n### `v1.9.5`\n\nTweaks\n\n* Track CPU count. [#110](https://github.com/newrelic/elixir_agent/pull/110)\n\n### `v1.9.4`\n\nFixes\n\n* Fix a bug in `PriorityQueue`. [#109](https://github.com/newrelic/elixir_agent/pull/109) Thanks @jasondew!\n\n### `v1.9.3`\n\nTweaks\n\n* Lowers the log level for harvester output. [#105](https://github.com/newrelic/elixir_agent/pull/105)\n\n### `v1.9.2`\n\nFixes\n\n* Fix a error that can happen if required attributes aren't captured. [#103](https://github.com/newrelic/elixir_agent/pull/103)\n\n### `v1.9.1`\n\nFixes\n\n* Fix the transaction event name attribute. [#100](https://github.com/newrelic/elixir_agent/pull/100)\n\n### `v1.9.0`\n\nFeatures\n\n* Use erlang's `httpc` client. [#70](https://github.com/newrelic/elixir_agent/pull/70)\n* Calculate and report the Total Time in a Transaction. [#98](https://github.com/newrelic/elixir_agent/pull/98)\n\nFixes\n\n* Attempt to flush each harvester upon graceful shutdown. [#94](https://github.com/newrelic/elixir_agent/pull/94)\n* Report External metrics based on transaction type. [#99](https://github.com/newrelic/elixir_agent/pull/99)\n\n-------\n\n### `v1.8.0`\n\nFeatures\n\n* Enable ignoring a Transaction. [#93](https://github.com/newrelic/elixir_agent/pull/93)\n* Track the number of processes spawned during a Transaction. [#88](https://github.com/newrelic/elixir_agent/pull/88)\n\nFixes\n\n* Handle error fetching AWS fargate metadata. [#89](https://github.com/newrelic/elixir_agent/pull/89)\n* Avoid a compiler warning for some traced functions. [#92](https://github.com/newrelic/elixir_agent/pull/92)\n* Prevent nested spans from duplicating attributes. [#97](https://github.com/newrelic/elixir_agent/pull/97)\n\n-------\n\n### `v1.7.0`\n\n* Support for \"Other\" (non-web) Transactions. [#84](https://github.com/newrelic/elixir_agent/pull/84)\n* Calculate and report Apdex metric. [#87](https://github.com/newrelic/elixir_agent/pull/87)\n\n-------\n\n### `v1.6.2`\n\n* Improve error logging when encountering a bad DT payload\n\n### `v1.6.1`\n\n* Clear up some deprecation warnings in Elixir `1.8.0`\n\n### `v1.6.0`\n\n* Add support for applying labels. [#79](https://github.com/newrelic/elixir_agent/pull/79)\n* Detect Heroku dyno hostnames. [#80](https://github.com/newrelic/elixir_agent/pull/80)\n* Provide better error structure for wrapped exceptions. [#78](https://github.com/newrelic/elixir_agent/pull/78)\n\n-------\n\n### `v1.5.0`\n\n* More flexible datastore metric reporting in prep for `Ecto` instrumentation. [#76](https://github.com/newrelic/elixir_agent/pull/76)\n\n-------\n\n### `v1.4.0`\n\n* Support nested Function Tracers in Transaction Traces and Distributed Tracing. [#58](https://github.com/newrelic/elixir_agent/pull/58)\n\n-------\n\n### `v1.3.2`\n\n* Specify `Plug` and `Cowboy` versions via `plug_cowboy` package.\n\n### `v1.3.1`\n\n* Properly handle when no app name has been supplied.\n\n### `v1.3.0`\n\n* Enable the NewRelic logger to use the Elixir Logger [#67](https://github.com/newrelic/elixir_agent/pull/67)\n* Properly assign multiple app names [#66](https://github.com/newrelic/elixir_agent/pull/66).\n* Log the collector method along with failed requests [#65](https://github.com/newrelic/elixir_agent/pull/65).\n\n-------\n\n### `v1.2.1`\n\n* Fix a bug that caused a subset of Span Events to be sent even though the Transaction wasn't sampled [#63](https://github.com/newrelic/elixir_agent/pull/63)\n\n### `v1.2.0`\n\n* Leverage the new Erlang `:logger` when running OTP 21 for improved Transaction / Error connecting [#55](https://github.com/newrelic/elixir_agent/pull/55)\n* Record process memory & reductions at the end of a Transaction [#56](https://github.com/newrelic/elixir_agent/pull/56)\n\n-------\n\n### `v1.1.0`\n\n* Report as `elixir`. [#19](https://github.com/newrelic/elixir_agent/pull/19)\n\nAPM now has first-class support for Elixir! Along with this agent upgrade, you will find the BEAM stats page availble with easy access to information about the VM, including Processes, Memory and Network. See https://github.com/newrelic/elixir_agent/wiki/BEAM-stats-page for more info.\n\n* Note: I haven't followed semver very well, from now on I'll be bumping the minor version for each release of new features, and reserve the patch for bugfixes.\n\n-------\n\n### `v1.0.5`\n\n* Report more Beam VM stats. [#38](https://github.com/newrelic/elixir_agent/pull/38), [#46](https://github.com/newrelic/elixir_agent/pull/46)\n* Report process stats for top consuming processes. [#41](https://github.com/newrelic/elixir_agent/pull/41)\n* Re-factor a few agent innards to enable transaction name and errors.\n\n### `v1.0.4`\n\n* Enable configuring Error collection via `:error_collector_enabled` [#36](https://github.com/newrelic/elixir_agent/pull/36) (Thanks @sb8244)\n\n### `v1.0.3`\n\n* Report basic CPU and Memory metrics [#34](https://github.com/newrelic/elixir_agent/pull/34)\n* Report caller metrics to enable relationship generation\n* Extend the timeout waiting for data to post to New Relic\n* Add `HTTPoison.request/5` instrumented function (Thanks @rhruiz)","ref":"changelog.html#changelog"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.36.1"}}